@@ -69,6 +69,10 @@ class JMan:
     def albarans(self):
         return accions.Albarans(con=self._con)
 
+    @property
+    def factures(self):
+        return accions.Factures(con=self._con)
+
     @property
     def recepcions(self):
         return accions.Recepcions(con=self._con)
