@@ -36,7 +36,7 @@ class Albarans:
         if len(tmp_params) > 0:
             tmp_query = "?"
             for xx in tmp_params:
-                tmp_query += xx
+                tmp_query += "&" + xx
 
         req = self._con.get(url=tmp_url + tmp_query)
         return req.json()
