@@ -45,8 +45,8 @@ class ConfigJavaman:
     def magatzem_gdis_id(self):
         return self._config["magatzem_gdis_id"]
 
-    def magatzem_silo_id(self):
-        return self._config["magatzem_silo_id"]
+    def magatzem_entrades_id(self):
+        return self._config["magatzem_entrades_id"]
 
     def magatzem_santa_llogaia_id(self):
         return self._config["magatzem_santa_llogaia_id"]
